@@ -92,17 +92,16 @@ def _get_span(request: Request, tracer: Tracer) -> SpanAbc:
 
 
 def _set_span_properties(span: SpanAbc, request: Request) -> None:
-    span_name = "{0} {1}".format(request.method.upper(), request.path)
+    span_name = f"{request.method.upper()} {request.path}"
     span.name(span_name)
     span.kind(SERVER)
     span.tag(HTTP_PATH, request.path)
     span.tag(HTTP_METHOD, request.method.upper())
 
     resource = request.match_info.route.resource
-    # available only in aiohttp >= 3.3.1
-    if getattr(resource, "canonical", None) is not None:
-        route = request.match_info.route.resource.canonical
-        span.tag(HTTP_ROUTE, route)
+    assert resource is not None
+    route = resource.canonical
+    span.tag(HTTP_ROUTE, route)
 
     _set_remote_endpoint(span, request)
 
@@ -181,7 +180,7 @@ def setup(
     *,
     skip_routes: Optional[Iterable[AbstractRoute]] = None,
     tracer_key: str = APP_AIOZIPKIN_KEY,
-    request_key: str = REQUEST_AIOZIPKIN_KEY
+    request_key: str = REQUEST_AIOZIPKIN_KEY,
 ) -> Application:
     """Sets required parameters in aiohttp applications for aiozipkin.
 
@@ -260,7 +259,7 @@ class ZipkinClientSignals:
         span = self._tracer.new_child(span_context)
         context._span = span
         span.start()
-        span_name = "client {0} {1}".format(p.method.upper(), p.url.path)
+        span_name = f"client {p.method.upper()} {p.url.path}"
         span.name(span_name)
         span.kind(CLIENT)
 
@@ -306,7 +305,7 @@ def make_trace_config(tracer: Tracer) -> aiohttp.TraceConfig:
     trace_config = aiohttp.TraceConfig()
     zipkin = ZipkinClientSignals(tracer)
 
-    trace_config.on_request_start.append(zipkin.on_request_start)  # type: ignore
-    trace_config.on_request_end.append(zipkin.on_request_end)  # type: ignore
-    trace_config.on_request_exception.append(zipkin.on_request_exception)  # type: ignore  # noqa
+    trace_config.on_request_start.append(zipkin.on_request_start)
+    trace_config.on_request_end.append(zipkin.on_request_end)
+    trace_config.on_request_exception.append(zipkin.on_request_exception)
     return trace_config
